==> cayenne-3.1.3-src.tar.gz: cayenne-3.1.3-src/modeler/cayenne-modeler/src/main/java/org/apache/cayenne/modeler/action/NavigateForwardAction.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.modeler.action;

import java.awt.event.ActionEvent;
import java.util.EventObject;

import org.apache.cayenne.modeler.Application;
import org.apache.cayenne.modeler.ProjectController;
import org.apache.cayenne.modeler.util.CayenneAction;

/**
 */
public class NavigateForwardAction extends CayenneAction {

    public static final String getActionName() {
        return "Move Forward";
    }

    /**
     * Constructor for Move Forward Action
     * @param name
     */
    public NavigateForwardAction(Application application) {
        super(getActionName(), application);
    }

    public String getIconName() {
        return "icon-forward_nav.gif";
    }

    /**
     * Moves to the previous element in the navigation history
     */
    public void performAction(ActionEvent e) {
        ProjectController mediator = getProjectController();
        EventObject newEvent = new EventObject(this);
        mediator.fireNavigationEvent(newEvent);
    }
}

==> cayenne-4.0.3-src.tar.gz: cayenne-4.0.3-src/modeler/cayenne-modeler/src/main/java/org/apache/cayenne/modeler/action/NavigateForwardAction.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.modeler.action;

import java.awt.event.ActionEvent;
import java.util.EventObject;

import org.apache.cayenne.modeler.Application;
import org.apache.cayenne.modeler.ProjectController;
import org.apache.cayenne.modeler.util.CayenneAction;

/**
 */
public class NavigateForwardAction extends CayenneAction {

    public static final String getActionName() {
        return "Move Forward";
    }

    /**
     * Constructor for Move Forward Action
     */
    public NavigateForwardAction(Application application) {
        super(getActionName(), application);
    }

    public String getIconName() {
        return "icon-forward.png";
    }

    /**
     * Moves to the previous element in the navigation history
     */
    public void performAction(ActionEvent e) {
        ProjectController mediator = getProjectController();
        EventObject newEvent = new EventObject(this);
        mediator.fireNavigationEvent(newEvent);
    }
}
